# Life after filoma

Here are some tools that work well with `filoma` for further data analysis and machine learning tasks.  
   
1. [**ydata-profiling**](https://github.com/ydataai/ydata-profiling): Generate detailed profiling reports from `filoma` dataframes to understand data distributions, correlations, and potential issues through interactive HTML reports with visualizations and statistics. 
[Open demo in a new tab](./life-after-filoma.html)  
2. More to be added soon!